# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dapr/proto/runtime/v1/dapr.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from dapr.proto.common.v1 import common_pb2 as dapr_dot_proto_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n dapr/proto/runtime/v1/dapr.proto\x12\x15\x64\x61pr.proto.runtime.v1\x1a\x19google/protobuf/any.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a!dapr/proto/common/v1/common.proto\"X\n\x14InvokeServiceRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\x07message\x18\x03 \x01(\x0b\x32#.dapr.proto.common.v1.InvokeRequest\"\xf5\x01\n\x0fGetStateRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12H\n\x0b\x63onsistency\x18\x03 \x01(\x0e\x32\x33.dapr.proto.common.v1.StateOptions.StateConsistency\x12\x46\n\x08metadata\x18\x04 \x03(\x0b\x32\x34.dapr.proto.runtime.v1.GetStateRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc9\x01\n\x13GetBulkStateRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12\x13\n\x0bparallelism\x18\x03 \x01(\x05\x12J\n\x08metadata\x18\x04 \x03(\x0b\x32\x38.dapr.proto.runtime.v1.GetBulkStateRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"K\n\x14GetBulkStateResponse\x12\x33\n\x05items\x18\x01 \x03(\x0b\x32$.dapr.proto.runtime.v1.BulkStateItem\"\xbe\x01\n\rBulkStateItem\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\r\n\x05\x65rror\x18\x04 \x01(\t\x12\x44\n\x08metadata\x18\x05 \x03(\x0b\x32\x32.dapr.proto.runtime.v1.BulkStateItem.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa8\x01\n\x10GetStateResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12G\n\x08metadata\x18\x03 \x03(\x0b\x32\x35.dapr.proto.runtime.v1.GetStateResponse.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x90\x02\n\x12\x44\x65leteStateRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12(\n\x04\x65tag\x18\x03 \x01(\x0b\x32\x1a.dapr.proto.common.v1.Etag\x12\x33\n\x07options\x18\x04 \x01(\x0b\x32\".dapr.proto.common.v1.StateOptions\x12I\n\x08metadata\x18\x05 \x03(\x0b\x32\x37.dapr.proto.runtime.v1.DeleteStateRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n\x16\x44\x65leteBulkStateRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12/\n\x06states\x18\x02 \x03(\x0b\x32\x1f.dapr.proto.common.v1.StateItem\"W\n\x10SaveStateRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12/\n\x06states\x18\x02 \x03(\x0b\x32\x1f.dapr.proto.common.v1.StateItem\"\xb1\x01\n\x11QueryStateRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\r\n\x05query\x18\x02 \x01(\t\x12H\n\x08metadata\x18\x03 \x03(\x0b\x32\x36.dapr.proto.runtime.v1.QueryStateRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x0eQueryStateItem\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"\xd7\x01\n\x12QueryStateResponse\x12\x36\n\x07results\x18\x01 \x03(\x0b\x32%.dapr.proto.runtime.v1.QueryStateItem\x12\r\n\x05token\x18\x02 \x01(\t\x12I\n\x08metadata\x18\x03 \x03(\x0b\x32\x37.dapr.proto.runtime.v1.QueryStateResponse.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdf\x01\n\x13PublishEventRequest\x12\x13\n\x0bpubsub_name\x18\x01 \x01(\t\x12\r\n\x05topic\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12\x19\n\x11\x64\x61ta_content_type\x18\x04 \x01(\t\x12J\n\x08metadata\x18\x05 \x03(\x0b\x32\x38.dapr.proto.runtime.v1.PublishEventRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc3\x01\n\x14InvokeBindingRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12K\n\x08metadata\x18\x03 \x03(\x0b\x32\x39.dapr.proto.runtime.v1.InvokeBindingRequest.MetadataEntry\x12\x11\n\toperation\x18\x04 \x01(\t\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa4\x01\n\x15InvokeBindingResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12L\n\x08metadata\x18\x02 \x03(\x0b\x32:.dapr.proto.runtime.v1.InvokeBindingResponse.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xad\x01\n\x10GetSecretRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12G\n\x08metadata\x18\x03 \x03(\x0b\x32\x35.dapr.proto.runtime.v1.GetSecretRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x82\x01\n\x11GetSecretResponse\x12@\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x32.dapr.proto.runtime.v1.GetSecretResponse.DataEntry\x1a+\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa8\x01\n\x14GetBulkSecretRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12K\n\x08metadata\x18\x02 \x03(\x0b\x32\x39.dapr.proto.runtime.v1.GetBulkSecretRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x85\x01\n\x0eSecretResponse\x12\x43\n\x07secrets\x18\x01 \x03(\x0b\x32\x32.dapr.proto.runtime.v1.SecretResponse.SecretsEntry\x1a.\n\x0cSecretsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb1\x01\n\x15GetBulkSecretResponse\x12\x44\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x36.dapr.proto.runtime.v1.GetBulkSecretResponse.DataEntry\x1aR\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.dapr.proto.runtime.v1.SecretResponse:\x02\x38\x01\"f\n\x1bTransactionalStateOperation\x12\x15\n\roperationType\x18\x01 \x01(\t\x12\x30\n\x07request\x18\x02 \x01(\x0b\x32\x1f.dapr.proto.common.v1.StateItem\"\x83\x02\n\x1e\x45xecuteStateTransactionRequest\x12\x11\n\tstoreName\x18\x01 \x01(\t\x12\x46\n\noperations\x18\x02 \x03(\x0b\x32\x32.dapr.proto.runtime.v1.TransactionalStateOperation\x12U\n\x08metadata\x18\x03 \x03(\x0b\x32\x43.dapr.proto.runtime.v1.ExecuteStateTransactionRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9e\x01\n\x19RegisterActorTimerRequest\x12\x12\n\nactor_type\x18\x01 \x01(\t\x12\x10\n\x08\x61\x63tor_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08\x64ue_time\x18\x04 \x01(\t\x12\x0e\n\x06period\x18\x05 \x01(\t\x12\x10\n\x08\x63\x61llback\x18\x06 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x07 \x01(\x0c\x12\x0b\n\x03ttl\x18\x08 \x01(\t\"Q\n\x1bUnregisterActorTimerRequest\x12\x12\n\nactor_type\x18\x01 \x01(\t\x12\x10\n\x08\x61\x63tor_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x8f\x01\n\x1cRegisterActorReminderRequest\x12\x12\n\nactor_type\x18\x01 \x01(\t\x12\x10\n\x08\x61\x63tor_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08\x64ue_time\x18\x04 \x01(\t\x12\x0e\n\x06period\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\x0c\x12\x0b\n\x03ttl\x18\x07 \x01(\t\"T\n\x1eUnregisterActorReminderRequest\x12\x12\n\nactor_type\x18\x01 \x01(\t\x12\x10\n\x08\x61\x63tor_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"f\n\x1aRenameActorReminderRequest\x12\x12\n\nactor_type\x18\x01 \x01(\t\x12\x10\n\x08\x61\x63tor_id\x18\x02 \x01(\t\x12\x10\n\x08old_name\x18\x03 \x01(\t\x12\x10\n\x08new_name\x18\x04 \x01(\t\"I\n\x14GetActorStateRequest\x12\x12\n\nactor_type\x18\x01 \x01(\t\x12\x10\n\x08\x61\x63tor_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"%\n\x15GetActorStateResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\x98\x01\n#ExecuteActorStateTransactionRequest\x12\x12\n\nactor_type\x18\x01 \x01(\t\x12\x10\n\x08\x61\x63tor_id\x18\x02 \x01(\t\x12K\n\noperations\x18\x03 \x03(\x0b\x32\x37.dapr.proto.runtime.v1.TransactionalActorStateOperation\"k\n TransactionalActorStateOperation\x12\x15\n\roperationType\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12#\n\x05value\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\"\xd4\x01\n\x12InvokeActorRequest\x12\x12\n\nactor_type\x18\x01 \x01(\t\x12\x10\n\x08\x61\x63tor_id\x18\x02 \x01(\t\x12\x0e\n\x06method\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\x12I\n\x08metadata\x18\x05 \x03(\x0b\x32\x37.dapr.proto.runtime.v1.InvokeActorRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"#\n\x13InvokeActorResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\xca\x02\n\x13GetMetadataResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x45\n\x13\x61\x63tive_actors_count\x18\x02 \x03(\x0b\x32(.dapr.proto.runtime.v1.ActiveActorsCount\x12J\n\x15registered_components\x18\x03 \x03(\x0b\x32+.dapr.proto.runtime.v1.RegisteredComponents\x12[\n\x11\x65xtended_metadata\x18\x04 \x03(\x0b\x32@.dapr.proto.runtime.v1.GetMetadataResponse.ExtendedMetadataEntry\x1a\x37\n\x15\x45xtendedMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"0\n\x11\x41\x63tiveActorsCount\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\"Y\n\x14RegisteredComponents\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x14\n\x0c\x63\x61pabilities\x18\x04 \x03(\t\"0\n\x12SetMetadataRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xbc\x01\n\x17GetConfigurationRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12N\n\x08metadata\x18\x03 \x03(\x0b\x32<.dapr.proto.runtime.v1.GetConfigurationRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbc\x01\n\x18GetConfigurationResponse\x12I\n\x05items\x18\x01 \x03(\x0b\x32:.dapr.proto.runtime.v1.GetConfigurationResponse.ItemsEntry\x1aU\n\nItemsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32\'.dapr.proto.common.v1.ConfigurationItem:\x02\x38\x01\"\xc8\x01\n\x1dSubscribeConfigurationRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12T\n\x08metadata\x18\x03 \x03(\x0b\x32\x42.dapr.proto.runtime.v1.SubscribeConfigurationRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"A\n\x1fUnsubscribeConfigurationRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"\xd4\x01\n\x1eSubscribeConfigurationResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12O\n\x05items\x18\x02 \x03(\x0b\x32@.dapr.proto.runtime.v1.SubscribeConfigurationResponse.ItemsEntry\x1aU\n\nItemsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32\'.dapr.proto.common.v1.ConfigurationItem:\x02\x38\x01\"?\n UnsubscribeConfigurationResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"f\n\x0eTryLockRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\x12\x12\n\nlock_owner\x18\x03 \x01(\t\x12\x17\n\x0f\x65xpiryInSeconds\x18\x04 \x01(\x05\"\"\n\x0fTryLockResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"L\n\rUnlockRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\x12\x12\n\nlock_owner\x18\x03 \x01(\t\"\xae\x01\n\x0eUnlockResponse\x12<\n\x06status\x18\x01 \x01(\x0e\x32,.dapr.proto.runtime.v1.UnlockResponse.Status\"^\n\x06Status\x12\x0b\n\x07SUCCESS\x10\x00\x12\x17\n\x13LOCK_DOES_NOT_EXIST\x10\x01\x12\x1a\n\x16LOCK_BELONGS_TO_OTHERS\x10\x02\x12\x12\n\x0eINTERNAL_ERROR\x10\x03\x32\xba\x16\n\x04\x44\x61pr\x12\x64\n\rInvokeService\x12+.dapr.proto.runtime.v1.InvokeServiceRequest\x1a$.dapr.proto.common.v1.InvokeResponse\"\x00\x12]\n\x08GetState\x12&.dapr.proto.runtime.v1.GetStateRequest\x1a\'.dapr.proto.runtime.v1.GetStateResponse\"\x00\x12i\n\x0cGetBulkState\x12*.dapr.proto.runtime.v1.GetBulkStateRequest\x1a+.dapr.proto.runtime.v1.GetBulkStateResponse\"\x00\x12N\n\tSaveState\x12\'.dapr.proto.runtime.v1.SaveStateRequest\x1a\x16.google.protobuf.Empty\"\x00\x12i\n\x10QueryStateAlpha1\x12(.dapr.proto.runtime.v1.QueryStateRequest\x1a).dapr.proto.runtime.v1.QueryStateResponse\"\x00\x12R\n\x0b\x44\x65leteState\x12).dapr.proto.runtime.v1.DeleteStateRequest\x1a\x16.google.protobuf.Empty\"\x00\x12Z\n\x0f\x44\x65leteBulkState\x12-.dapr.proto.runtime.v1.DeleteBulkStateRequest\x1a\x16.google.protobuf.Empty\"\x00\x12j\n\x17\x45xecuteStateTransaction\x12\x35.dapr.proto.runtime.v1.ExecuteStateTransactionRequest\x1a\x16.google.protobuf.Empty\"\x00\x12T\n\x0cPublishEvent\x12*.dapr.proto.runtime.v1.PublishEventRequest\x1a\x16.google.protobuf.Empty\"\x00\x12l\n\rInvokeBinding\x12+.dapr.proto.runtime.v1.InvokeBindingRequest\x1a,.dapr.proto.runtime.v1.InvokeBindingResponse\"\x00\x12`\n\tGetSecret\x12\'.dapr.proto.runtime.v1.GetSecretRequest\x1a(.dapr.proto.runtime.v1.GetSecretResponse\"\x00\x12l\n\rGetBulkSecret\x12+.dapr.proto.runtime.v1.GetBulkSecretRequest\x1a,.dapr.proto.runtime.v1.GetBulkSecretResponse\"\x00\x12`\n\x12RegisterActorTimer\x12\x30.dapr.proto.runtime.v1.RegisterActorTimerRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x64\n\x14UnregisterActorTimer\x12\x32.dapr.proto.runtime.v1.UnregisterActorTimerRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x66\n\x15RegisterActorReminder\x12\x33.dapr.proto.runtime.v1.RegisterActorReminderRequest\x1a\x16.google.protobuf.Empty\"\x00\x12j\n\x17UnregisterActorReminder\x12\x35.dapr.proto.runtime.v1.UnregisterActorReminderRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x62\n\x13RenameActorReminder\x12\x31.dapr.proto.runtime.v1.RenameActorReminderRequest\x1a\x16.google.protobuf.Empty\"\x00\x12l\n\rGetActorState\x12+.dapr.proto.runtime.v1.GetActorStateRequest\x1a,.dapr.proto.runtime.v1.GetActorStateResponse\"\x00\x12t\n\x1c\x45xecuteActorStateTransaction\x12:.dapr.proto.runtime.v1.ExecuteActorStateTransactionRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x66\n\x0bInvokeActor\x12).dapr.proto.runtime.v1.InvokeActorRequest\x1a*.dapr.proto.runtime.v1.InvokeActorResponse\"\x00\x12{\n\x16GetConfigurationAlpha1\x12..dapr.proto.runtime.v1.GetConfigurationRequest\x1a/.dapr.proto.runtime.v1.GetConfigurationResponse\"\x00\x12\x8f\x01\n\x1cSubscribeConfigurationAlpha1\x12\x34.dapr.proto.runtime.v1.SubscribeConfigurationRequest\x1a\x35.dapr.proto.runtime.v1.SubscribeConfigurationResponse\"\x00\x30\x01\x12\x93\x01\n\x1eUnsubscribeConfigurationAlpha1\x12\x36.dapr.proto.runtime.v1.UnsubscribeConfigurationRequest\x1a\x37.dapr.proto.runtime.v1.UnsubscribeConfigurationResponse\"\x00\x12`\n\rTryLockAlpha1\x12%.dapr.proto.runtime.v1.TryLockRequest\x1a&.dapr.proto.runtime.v1.TryLockResponse\"\x00\x12]\n\x0cUnlockAlpha1\x12$.dapr.proto.runtime.v1.UnlockRequest\x1a%.dapr.proto.runtime.v1.UnlockResponse\"\x00\x12S\n\x0bGetMetadata\x12\x16.google.protobuf.Empty\x1a*.dapr.proto.runtime.v1.GetMetadataResponse\"\x00\x12R\n\x0bSetMetadata\x12).dapr.proto.runtime.v1.SetMetadataRequest\x1a\x16.google.protobuf.Empty\"\x00\x12<\n\x08Shutdown\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\"\x00\x42i\n\nio.dapr.v1B\nDaprProtosZ1github.com/dapr/dapr/pkg/proto/runtime/v1;runtime\xaa\x02\x1b\x44\x61pr.Client.Autogen.Grpc.v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dapr.proto.runtime.v1.dapr_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\nio.dapr.v1B\nDaprProtosZ1github.com/dapr/dapr/pkg/proto/runtime/v1;runtime\252\002\033Dapr.Client.Autogen.Grpc.v1'
  _GETSTATEREQUEST_METADATAENTRY._options = None
  _GETSTATEREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _GETBULKSTATEREQUEST_METADATAENTRY._options = None
  _GETBULKSTATEREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _BULKSTATEITEM_METADATAENTRY._options = None
  _BULKSTATEITEM_METADATAENTRY._serialized_options = b'8\001'
  _GETSTATERESPONSE_METADATAENTRY._options = None
  _GETSTATERESPONSE_METADATAENTRY._serialized_options = b'8\001'
  _DELETESTATEREQUEST_METADATAENTRY._options = None
  _DELETESTATEREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _QUERYSTATEREQUEST_METADATAENTRY._options = None
  _QUERYSTATEREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _QUERYSTATERESPONSE_METADATAENTRY._options = None
  _QUERYSTATERESPONSE_METADATAENTRY._serialized_options = b'8\001'
  _PUBLISHEVENTREQUEST_METADATAENTRY._options = None
  _PUBLISHEVENTREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _INVOKEBINDINGREQUEST_METADATAENTRY._options = None
  _INVOKEBINDINGREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _INVOKEBINDINGRESPONSE_METADATAENTRY._options = None
  _INVOKEBINDINGRESPONSE_METADATAENTRY._serialized_options = b'8\001'
  _GETSECRETREQUEST_METADATAENTRY._options = None
  _GETSECRETREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _GETSECRETRESPONSE_DATAENTRY._options = None
  _GETSECRETRESPONSE_DATAENTRY._serialized_options = b'8\001'
  _GETBULKSECRETREQUEST_METADATAENTRY._options = None
  _GETBULKSECRETREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _SECRETRESPONSE_SECRETSENTRY._options = None
  _SECRETRESPONSE_SECRETSENTRY._serialized_options = b'8\001'
  _GETBULKSECRETRESPONSE_DATAENTRY._options = None
  _GETBULKSECRETRESPONSE_DATAENTRY._serialized_options = b'8\001'
  _EXECUTESTATETRANSACTIONREQUEST_METADATAENTRY._options = None
  _EXECUTESTATETRANSACTIONREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _INVOKEACTORREQUEST_METADATAENTRY._options = None
  _INVOKEACTORREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _GETMETADATARESPONSE_EXTENDEDMETADATAENTRY._options = None
  _GETMETADATARESPONSE_EXTENDEDMETADATAENTRY._serialized_options = b'8\001'
  _GETCONFIGURATIONREQUEST_METADATAENTRY._options = None
  _GETCONFIGURATIONREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _GETCONFIGURATIONRESPONSE_ITEMSENTRY._options = None
  _GETCONFIGURATIONRESPONSE_ITEMSENTRY._serialized_options = b'8\001'
  _SUBSCRIBECONFIGURATIONREQUEST_METADATAENTRY._options = None
  _SUBSCRIBECONFIGURATIONREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _SUBSCRIBECONFIGURATIONRESPONSE_ITEMSENTRY._options = None
  _SUBSCRIBECONFIGURATIONRESPONSE_ITEMSENTRY._serialized_options = b'8\001'
  _INVOKESERVICEREQUEST._serialized_start=150
  _INVOKESERVICEREQUEST._serialized_end=238
  _GETSTATEREQUEST._serialized_start=241
  _GETSTATEREQUEST._serialized_end=486
  _GETSTATEREQUEST_METADATAENTRY._serialized_start=439
  _GETSTATEREQUEST_METADATAENTRY._serialized_end=486
  _GETBULKSTATEREQUEST._serialized_start=489
  _GETBULKSTATEREQUEST._serialized_end=690
  _GETBULKSTATEREQUEST_METADATAENTRY._serialized_start=439
  _GETBULKSTATEREQUEST_METADATAENTRY._serialized_end=486
  _GETBULKSTATERESPONSE._serialized_start=692
  _GETBULKSTATERESPONSE._serialized_end=767
  _BULKSTATEITEM._serialized_start=770
  _BULKSTATEITEM._serialized_end=960
  _BULKSTATEITEM_METADATAENTRY._serialized_start=439
  _BULKSTATEITEM_METADATAENTRY._serialized_end=486
  _GETSTATERESPONSE._serialized_start=963
  _GETSTATERESPONSE._serialized_end=1131
  _GETSTATERESPONSE_METADATAENTRY._serialized_start=439
  _GETSTATERESPONSE_METADATAENTRY._serialized_end=486
  _DELETESTATEREQUEST._serialized_start=1134
  _DELETESTATEREQUEST._serialized_end=1406
  _DELETESTATEREQUEST_METADATAENTRY._serialized_start=439
  _DELETESTATEREQUEST_METADATAENTRY._serialized_end=486
  _DELETEBULKSTATEREQUEST._serialized_start=1408
  _DELETEBULKSTATEREQUEST._serialized_end=1501
  _SAVESTATEREQUEST._serialized_start=1503
  _SAVESTATEREQUEST._serialized_end=1590
  _QUERYSTATEREQUEST._serialized_start=1593
  _QUERYSTATEREQUEST._serialized_end=1770
  _QUERYSTATEREQUEST_METADATAENTRY._serialized_start=439
  _QUERYSTATEREQUEST_METADATAENTRY._serialized_end=486
  _QUERYSTATEITEM._serialized_start=1772
  _QUERYSTATEITEM._serialized_end=1844
  _QUERYSTATERESPONSE._serialized_start=1847
  _QUERYSTATERESPONSE._serialized_end=2062
  _QUERYSTATERESPONSE_METADATAENTRY._serialized_start=439
  _QUERYSTATERESPONSE_METADATAENTRY._serialized_end=486
  _PUBLISHEVENTREQUEST._serialized_start=2065
  _PUBLISHEVENTREQUEST._serialized_end=2288
  _PUBLISHEVENTREQUEST_METADATAENTRY._serialized_start=439
  _PUBLISHEVENTREQUEST_METADATAENTRY._serialized_end=486
  _INVOKEBINDINGREQUEST._serialized_start=2291
  _INVOKEBINDINGREQUEST._serialized_end=2486
  _INVOKEBINDINGREQUEST_METADATAENTRY._serialized_start=439
  _INVOKEBINDINGREQUEST_METADATAENTRY._serialized_end=486
  _INVOKEBINDINGRESPONSE._serialized_start=2489
  _INVOKEBINDINGRESPONSE._serialized_end=2653
  _INVOKEBINDINGRESPONSE_METADATAENTRY._serialized_start=439
  _INVOKEBINDINGRESPONSE_METADATAENTRY._serialized_end=486
  _GETSECRETREQUEST._serialized_start=2656
  _GETSECRETREQUEST._serialized_end=2829
  _GETSECRETREQUEST_METADATAENTRY._serialized_start=439
  _GETSECRETREQUEST_METADATAENTRY._serialized_end=486
  _GETSECRETRESPONSE._serialized_start=2832
  _GETSECRETRESPONSE._serialized_end=2962
  _GETSECRETRESPONSE_DATAENTRY._serialized_start=2919
  _GETSECRETRESPONSE_DATAENTRY._serialized_end=2962
  _GETBULKSECRETREQUEST._serialized_start=2965
  _GETBULKSECRETREQUEST._serialized_end=3133
  _GETBULKSECRETREQUEST_METADATAENTRY._serialized_start=439
  _GETBULKSECRETREQUEST_METADATAENTRY._serialized_end=486
  _SECRETRESPONSE._serialized_start=3136
  _SECRETRESPONSE._serialized_end=3269
  _SECRETRESPONSE_SECRETSENTRY._serialized_start=3223
  _SECRETRESPONSE_SECRETSENTRY._serialized_end=3269
  _GETBULKSECRETRESPONSE._serialized_start=3272
  _GETBULKSECRETRESPONSE._serialized_end=3449
  _GETBULKSECRETRESPONSE_DATAENTRY._serialized_start=3367
  _GETBULKSECRETRESPONSE_DATAENTRY._serialized_end=3449
  _TRANSACTIONALSTATEOPERATION._serialized_start=3451
  _TRANSACTIONALSTATEOPERATION._serialized_end=3553
  _EXECUTESTATETRANSACTIONREQUEST._serialized_start=3556
  _EXECUTESTATETRANSACTIONREQUEST._serialized_end=3815
  _EXECUTESTATETRANSACTIONREQUEST_METADATAENTRY._serialized_start=439
  _EXECUTESTATETRANSACTIONREQUEST_METADATAENTRY._serialized_end=486
  _REGISTERACTORTIMERREQUEST._serialized_start=3818
  _REGISTERACTORTIMERREQUEST._serialized_end=3976
  _UNREGISTERACTORTIMERREQUEST._serialized_start=3978
  _UNREGISTERACTORTIMERREQUEST._serialized_end=4059
  _REGISTERACTORREMINDERREQUEST._serialized_start=4062
  _REGISTERACTORREMINDERREQUEST._serialized_end=4205
  _UNREGISTERACTORREMINDERREQUEST._serialized_start=4207
  _UNREGISTERACTORREMINDERREQUEST._serialized_end=4291
  _RENAMEACTORREMINDERREQUEST._serialized_start=4293
  _RENAMEACTORREMINDERREQUEST._serialized_end=4395
  _GETACTORSTATEREQUEST._serialized_start=4397
  _GETACTORSTATEREQUEST._serialized_end=4470
  _GETACTORSTATERESPONSE._serialized_start=4472
  _GETACTORSTATERESPONSE._serialized_end=4509
  _EXECUTEACTORSTATETRANSACTIONREQUEST._serialized_start=4512
  _EXECUTEACTORSTATETRANSACTIONREQUEST._serialized_end=4664
  _TRANSACTIONALACTORSTATEOPERATION._serialized_start=4666
  _TRANSACTIONALACTORSTATEOPERATION._serialized_end=4773
  _INVOKEACTORREQUEST._serialized_start=4776
  _INVOKEACTORREQUEST._serialized_end=4988
  _INVOKEACTORREQUEST_METADATAENTRY._serialized_start=439
  _INVOKEACTORREQUEST_METADATAENTRY._serialized_end=486
  _INVOKEACTORRESPONSE._serialized_start=4990
  _INVOKEACTORRESPONSE._serialized_end=5025
  _GETMETADATARESPONSE._serialized_start=5028
  _GETMETADATARESPONSE._serialized_end=5358
  _GETMETADATARESPONSE_EXTENDEDMETADATAENTRY._serialized_start=5303
  _GETMETADATARESPONSE_EXTENDEDMETADATAENTRY._serialized_end=5358
  _ACTIVEACTORSCOUNT._serialized_start=5360
  _ACTIVEACTORSCOUNT._serialized_end=5408
  _REGISTEREDCOMPONENTS._serialized_start=5410
  _REGISTEREDCOMPONENTS._serialized_end=5499
  _SETMETADATAREQUEST._serialized_start=5501
  _SETMETADATAREQUEST._serialized_end=5549
  _GETCONFIGURATIONREQUEST._serialized_start=5552
  _GETCONFIGURATIONREQUEST._serialized_end=5740
  _GETCONFIGURATIONREQUEST_METADATAENTRY._serialized_start=439
  _GETCONFIGURATIONREQUEST_METADATAENTRY._serialized_end=486
  _GETCONFIGURATIONRESPONSE._serialized_start=5743
  _GETCONFIGURATIONRESPONSE._serialized_end=5931
  _GETCONFIGURATIONRESPONSE_ITEMSENTRY._serialized_start=5846
  _GETCONFIGURATIONRESPONSE_ITEMSENTRY._serialized_end=5931
  _SUBSCRIBECONFIGURATIONREQUEST._serialized_start=5934
  _SUBSCRIBECONFIGURATIONREQUEST._serialized_end=6134
  _SUBSCRIBECONFIGURATIONREQUEST_METADATAENTRY._serialized_start=439
  _SUBSCRIBECONFIGURATIONREQUEST_METADATAENTRY._serialized_end=486
  _UNSUBSCRIBECONFIGURATIONREQUEST._serialized_start=6136
  _UNSUBSCRIBECONFIGURATIONREQUEST._serialized_end=6201
  _SUBSCRIBECONFIGURATIONRESPONSE._serialized_start=6204
  _SUBSCRIBECONFIGURATIONRESPONSE._serialized_end=6416
  _SUBSCRIBECONFIGURATIONRESPONSE_ITEMSENTRY._serialized_start=5846
  _SUBSCRIBECONFIGURATIONRESPONSE_ITEMSENTRY._serialized_end=5931
  _UNSUBSCRIBECONFIGURATIONRESPONSE._serialized_start=6418
  _UNSUBSCRIBECONFIGURATIONRESPONSE._serialized_end=6481
  _TRYLOCKREQUEST._serialized_start=6483
  _TRYLOCKREQUEST._serialized_end=6585
  _TRYLOCKRESPONSE._serialized_start=6587
  _TRYLOCKRESPONSE._serialized_end=6621
  _UNLOCKREQUEST._serialized_start=6623
  _UNLOCKREQUEST._serialized_end=6699
  _UNLOCKRESPONSE._serialized_start=6702
  _UNLOCKRESPONSE._serialized_end=6876
  _UNLOCKRESPONSE_STATUS._serialized_start=6782
  _UNLOCKRESPONSE_STATUS._serialized_end=6876
  _DAPR._serialized_start=6879
  _DAPR._serialized_end=9753
# @@protoc_insertion_point(module_scope)
